
# diskTest1.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Various tests of the Poincare disk geometry classes 
  and functions in pgeom.py. (Also see diskTest2.py.)

  Based on the in[2] code at
  https://github.com/cduck/hyperbolic/blob/master/examples/poincare.ipynb
  that generates hypercycleTest1.svg

  Generates diskTest1.png
'''

import math
from geom import *
from pgeom import *

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# a red d-line segment ending in green points
p1 = Point(0, 0.5)
p2 = Point(0.5,-0.5)
d.draw(p1, stroke='green', fill='green')
d.draw(p2, stroke='green', fill='green')
hl = Line.points(p1, p2, segment=True)
d.draw(hl, stroke='red')

# another red d-line segment
hl2 = Line.points(Point(-0.5,0.5), Point(-0.3,-0.3), segment=True)
d.draw(hl2, stroke='red')

# an 'infinite' blue d-line, touching the boundary at 
# the two ideals at the specified angles (0 is the
# compass point West)
hl3 = Line.points(Ideal.degree(-70), Ideal.degree(-200))
d.draw(hl3, stroke='blue')

# a thick green point
p = Point(-0.6, -0.1)
d.draw(p, radius=0.03, stroke='green', fill='green')

# a blue dline perpendicular to the point
hlp = hl3.perpendicular(p)
d.draw(hlp)

# ten circles each 'centered' on the green point
circles = [Circle.center_radius(p, 0.1*(i*2+2.5)) 
                               for i in range(10)]
for circ in circles:
  d.draw(circ, stroke='green', opacity=0.6)


# an orange 'triangle' made of three d-lines
hlp1 = Line.points(Ideal.degree(0), 
                   Ideal.degree(-360/3))

hlp2 = Line.points(Ideal.degree(-360/3), 
                   Ideal.degree(-360/3*2))

hlp3 = Line.points(Ideal.degree(-360/3*2), 
                   Ideal.degree(0))
d.draw(hlp1, stroke='orange')
d.draw(hlp2, stroke='orange')
d.draw(hlp3, stroke='orange')

# dots at various 'compass' points on the disk
drawDot(d, -1, 0, color='orange')
drawDot(d, 1, 0, color='green')
drawDot(d, 0, 1, color='red')
drawDot(d, 0, -1, color='brown')
drawDot(d, 0, 0)

saveDrawing(d, 'diskTest1.png')
