
# diskTest2.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Various tests of the Poincare disk geometry classes 
  and functions in pgeom.py. (Also see diskTest1.py.)

  Based on the in[4] code at
  https://github.com/cduck/hyperbolic/blob/master/examples/poincare.ipynb
  that generates hypercycleTest2.svg

  Generates diskTest2.png
'''

import math
from geom import *
from pgeom import *

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver')# disc boundary

ps1 = Point(0.5, -0.25)
pe1 = Point(0.7, -0.35)
hl1 = Line.points(ps1, pe1)

ps2 = Point(-0.5, -0.25)
pe2 = Point(-0.7, -0.35)
hl2 = Line.points(ps2, pe2, segment=True)

ps3 = Point(0.5, -0.2)
pe3 = Point(0.1, -0.8)
hl3 = Line.points(ps3, pe3, segment=True)

ps4 = Point(0.5, 0.2)
pe4 = Point(0.1, 0.8)
hl4 = Line.points(ps4, pe4)



d.draw(hl1, stroke_dasharray='.02,.02')
d.draw(hl2, stroke_dasharray='.02,.02')

d.draw(hl3, hwidth=0.6, stroke='black')
d.draw(hl4, hwidth=0.6, stroke='black')

ls = dict(stroke='red', fill='none')
for p in [ps1,pe1, ps2, pe2, ps3, pe3, ps4, pe4]:
  d.draw(p, radius=0.02, **ls)

saveDrawing(d, 'diskTest2.png')