
# geomTests.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Tests of Euclidean geometry classes and 
  intersection functions in geom.py.
  Generates geomTests.png
'''

import math
from geom import *


d = createDrawing(winWidth=4)
drawAxes(d)

seg = ESegment(0,0,2,2)
p = seg.perpendicular(2,0, length=math.sqrt(2))
print("Perp p:", p)
print("Len:", math.hypot(p.x2-p.x1, p.y2-p.y1))
print("Angle:", math.atan2(p.y2-p.y1, p.x2-p.x1)*180/math.pi)

c1 = ECircle(-1, 0, 2)
c2 = ECircle(1, 0, 3)
print("rad line 1:", ESegment.radicalAxis(c1,c2))

c1 = ECircle(-1000-1, 0, 1000)
c2 = ECircle(1000+2, 10, 1000)
print("rad line 2:", ESegment.radicalAxis(c1,c2))

# draw two circles and segments
circ1 = ECircle(-1,1,math.sqrt(8)-1)
circ2 = ECircle(1,-1,1)
seg1 = ESegment(2,-2, -1,0)
seg2 = ESegment(-2,0, 2,-1)
d.draw(circ1, stroke='red')
d.draw(circ2, stroke='orange')
d.draw(seg1)
d.draw(seg2, stroke='green')


arc1 = EArc(0, 0, 2, 180, 270)
d.draw(arc1)

line3 = ELine(1,1, 1)
print("reflection:", line3.reflect(9, 5))

# ---------------------
print("\nCircle-Circle Intersects")
try:
  x1, y1, x2, y2 = circleCircle(circ1, circ2)
  print("CC Points:", ptStr(x1, y1), ptStr(x2, y2))
  dotLabel(d, "CC-1", x1, y1)
  dotLabel(d, "CC-2", x2, y2, color='orange')
except SingleIntersection as e:
  x1, y1 = e.args
  print('CC Point:', ptStr(x1, y1))
  dotLabel(d, "CC", x1, y1)
except NoIntersection:
  print('No intersection')
except InfiniteIntersections as e:
  print('Infinite')


# ---------------------
print("\nCircle-Segment Intersects")
try:
  x1, y1, x2, y2 = circleSeg(circ2, seg1)
  print("CS Points:", ptStr(x1, y1), ", ", ptStr(x2, y2))
  dotLabel(d, "CS-1", x1, y1)
  dotLabel(d, "CS-2", x2, y2, color='orange')
except SingleIntersection as e:
  x1, y1 = e.args
  print("CS Point:", ptStr(x1, y1))
  dotLabel(d, "CS", x1, y1)
except NoIntersection:
  print('No intersection')


# ---------------------
print("\nSegment-Segment Intersects")
try:
  x1, y1 = segSeg(seg1,seg2)
  print("SS Point:", ptStr(x1, y1))
  dotLabel(d, "SS", x1, y1)
except NoIntersection:
  print('No intersection')
except InfiniteIntersections as e:
  print('Infinite')

saveDrawing(d, 'geomTests.png')

