
# hexMirror.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Mirror transformation of a hexagon
  Generates hexMirror.png
'''

import math
from geom import *
from pgeom import *

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# a regular hexagon (drawn in blue)
p = 6; q = 4
pts = polyVerts(p, q)
edges = toEdges(pts)
for edge in edges:
  d.draw(edge)
print("Edges:", edges)
print("\nVerts:", pts)
r = polyRadius(p, q)
print("\nRadius:", r)

# label points 0 and 1
p0 = pts[0]
p1 = pts[1]
d.draw(p0, radius=0.02, fill='red')
drawLabel(d, "p0", p0.x+0.07, p0.y, size=8)
d.draw(p1, radius=0.02, fill='green')
drawLabel(d, "p1", p1.x+0.07, p1.y, size=8)

# mirror the hexagon in the edge p0--p1
m1 = Transform.mirror(p0, p1)
mVerts = m1.asList(pts)
mEdges = toEdges(mVerts)
for edge in mEdges:
  d.draw(edge, stroke='orange')

saveDrawing(d,'hexMirror.png')
