
# invTangents.py
# Ogilvy, C.S. "Excursions in Geometry", Dover, 1990
# Chap 4, Fig. 29
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Invert a series of blue circles that all have a
  tangent to the Y axis. The thick blue circle 
  which passes through the origin 
  intersects all of these at the same angle, which
  is apparent by looking how its inverse (an orange
  line) intersects their inverted lines. 

  Generates invTangents.png
'''


import math
from geom import *

d = createDrawing(5)
drawAxes(d)

ic = ECircle(0, 0, 1)  # circle used for inversion
d.draw(ic, stroke='green')

circles = [ ECircle(-0.5, 0, 0.5),  ECircle(0.5, 0, 0.5),
            ECircle(-1, 0, 1),   ECircle(1, 0, 1),
            ECircle(-0.75, 0, 0.75),  ECircle(0.75, 0, 0.75)
          ]
# the thick blue line; and its inversion
bigC = ECircle(1, -1, math.sqrt(2))
d.draw(bigC, stroke_width=0.02)
bigInv = bigC.invert(ic)
d.draw(bigInv, stroke='orange', stroke_width=0.02)

for circ in circles:
  d.draw(circ)
  inv = circ.invert(ic)
  d.draw(inv, stroke='orange')
  print(f"angle to: {bigInv.angleTo(inv):.3f}")
         # the same value; 45 degs in this case

saveDrawing(d,'invTangents.png')

