
# inverts.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Invert a red circle touching the inversion circle
  into a vertical line that's also touching the
  inversion circle, and label some points.
  Generates inverts.png

  Under inversion with respect to a circle with centre O:
  * a line punctured at O maps onto the same line punctured at O;
  * a line not through O maps onto a circle punctured at O;
  * a circle punctured at O maps onto a line not through O;
  * a circle not through O maps onto a circle not through O.
'''

import math
from geom import *

d = createDrawing(winWidth=6)
drawAxes(d)


ic = ECircle(0, 0, 2)  # circle used for inversion
c = ECircle(1, 0, 1)
d.draw(ic)
d.draw(c, stroke='green', stroke_width=0.02)

inv = c.invert(ic)
d.draw(inv, stroke='red', stroke_width=0.02)

pts = c.getCoords(10)
uPts = []
for i, pt in enumerate(pts):
  drawDot(d, *pt, radius = 0.05)
  drawLabel(d, "p"+str(i), pt[0]+0.2, pt[1])

  iPt = invertPt(*pt, ic.cx, ic.cy, ic.r)
  if not iPt == None:
    drawDot(d, *iPt, radius = 0.05)
    drawLabel(d, "i"+str(i), iPt[0]+0.15, iPt[1])
  
saveDrawing(d, 'inverts.png')

