
# mirrorPoints.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Based on the in[5] code at
  https://github.com/cduck/hyperbolic/blob/master/examples/poincare.ipynb
  that generates mirrorTest.svg

  Generates mirrorPoints.png
'''

import math
from geom import *
from pgeom import *

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# blue d-line running through p1 and p2
p1 = Point(0, 0.5)
p2 = Point(0.5, -0.5)
# d.draw(p1, stroke='green', fill='green')
# d.draw(p2, stroke='green', fill='green')
hl = Line.points(p1, p2)
d.draw(hl)

# create a mirror transform through the d-line's points
mirror = Transform.mirror(p1, p2)

pts = [  # the points form a cross through the origin
  Point(0,-0.1), Point(0,-0.3), Point(0,-0.5), 
  Point(0,-0.7), Point(0,-0.9),
  Point(0.1,0), Point(0.3,0), Point(0.5,0), 
  Point(0.7,0), Point(0.9,0),
  Point(0,0.1), Point(0,0.3), Point(0,0.5), 
  Point(0,0.7), Point(0,0.9),
  Point(-0.1,0), Point(-0.3,0), Point(-0.5,0), 
  Point(-0.7,0), Point(-0.9,0),
]
# display the numbered points in grey
for i, pt in enumerate(pts):
  d.draw(pt, radius=0.04, stroke='silver', fill='silver')
  drawLabel(d, str(i), *pt, size=6)

# mirror all the points, keeping the numbering
# the cross shape is mirrored in the d-line
mPts = mirror.asList(pts)
for i, pt in enumerate(mPts):
  d.draw(pt, radius=0.04, stroke='orange', fill='orange')
  drawLabel(d, str(i), *pt, color='green', size=6)

saveDrawing(d, 'mirrorPoints.png')
