
# pappusChain.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  The application of inversion to the Pappus chain problem
  https://en.wikipedia.org/wiki/Pappus_chain

  The circles correspond to those drawn in the 
  "Epic Circles" Numberphile video
  https://www.youtube.com/watch?v=sG_6nlMZ8f4

  Generates pappusChain.png
'''

import math
from geom import *

d = createDrawing(winWidth=3) 
drawAxes(d)

ic = ECircle(-1, 0, 1)   # circle used for inversion
d.draw(ic)

c0 = ECircle(0, 0, 1)
c1 = ECircle(-0.5, 0, 0.5)
# red and blue circles define an arbelos
# they both pass through the center of the inversion circle
d.draw(c0, stroke='blue', stroke_width=0.02)
d.draw(c1, stroke='red', stroke_width=0.02)

c2 = ECircle(0.5, 0, 0.5)
c3 = ECircle(0, 2/3, 1/3)
c4 = ECircle(-1/2, 2/3, 1/6)
# circles that are tangents to the red and blue circles
d.draw(c2, stroke='green', stroke_width=0.02)
d.draw(c3, stroke='orange', stroke_width=0.03)
d.draw(c4, stroke='brown', stroke_width=0.02)

# the arbelos circles invert to become red and blue lines
iC0 = c0.invert(ic)
iC1 = c1.invert(ic)
print("Inversion of c0:", iC0)
print("Inversion of c1:", iC1)
d.draw( iC0, stroke='blue', stroke_width=0.02)
d.draw( iC1, stroke='red', stroke_width=0.02)

# the tangent circles invert to circles between the
# red and blue lines, ascending from the x-axis
iC2 = c2.invert(ic)
iC3 = c3.invert(ic)
iC4 = c4.invert(ic)
print("Inversion of c2:", iC2)  # same radii
print("Inversion of c3:", iC3)
print("Inversion of c3:", iC4)
d.draw( iC2, stroke='green', stroke_width=0.02)
d.draw( iC3, stroke='orange', stroke_width=0.03)
d.draw( iC4, stroke='brown', stroke_width=0.02)

saveDrawing(d, 'pappus.png')

