
# pappus2.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  The application of inversion to the Pappus chain problem
  https://en.wikipedia.org/wiki/Pappus_chain

  This version generates the circles in the chain
  using papCircle() using math on the Wiki page

  Generates pappus2.png
'''

import math
from geom import *


def papCircle(n, r):
  # the nth circle in the chain
  denom = n*n*(1-r)*(1-r) + r
  xn = r*(1+r)/(2*denom)
  yn = n*r*(1-r)/denom
  rn = (1-r)*r/(2*denom)
  return ECircle(xn, yn, rn)


d = createDrawing() 
drawAxes(d)

ic = ECircle(0, 0, 1/2)   # circle used for inversion
d.draw(ic)

# two black circles define an arbelos
# they both pass through the center of the inversion circle
ac = ECircle(1/3, 0, 1/3)
d.draw(ac, stroke='black')
ab = ECircle(1/2, 0, 1/2)
d.draw(ab, stroke='black')

# the arbelos circles invert to become black lines
i_ac = ac.invert(ic)
d.draw(i_ac, stroke='black')
i_ab = ab.invert(ic)
d.draw(i_ab, stroke='black')


# tangent circles that invert to circles between the
# black lines, ascending from the x-axis
cols = ['blue', 'red', 'green', 'orange', 'brown']
for i in range(7):
  cn = papCircle(i, 2/3)
  d.draw(cn, stroke=cols[i%len(cols)], stroke_width=0.02)
  iCn = cn.invert(ic)
  d.draw( iCn, stroke=cols[i%len(cols)], stroke_width=0.02)

saveDrawing(d, 'pappus2.png')

