
# polyCircle.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Produces a single regular polgon based on supplied
  p and q values, drawn inside a circle.

  polyVerts() calculates the coordinates
  for a regular polygon by considering the right-angled
  triangle that makes up half of one side. The angles
  of that triangle are A, B, and C.

    p = the number of sides of the polygon;
    q = the number of polygons that meet at
        a vertex

  For a hyperbolic regular polygon
  (p-2) * (q-2) > 4

  Generates polyCircle.png
'''

import math

from geom import *
from pgeom import *
import drawsvg

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

print("Some (p,q)'s: (6,4), (8,3), (10,3)...")
print("where (p-2) * (q-2) > 4")
p, q = map(int, input("p q? ").split())
pts = polyVerts(p, q)
edges = toEdges(pts)
for edge in edges:
  d.draw(edge)

# draw a circle around the polygon
r = polyRadius(p, q)
print("Radius of polygon:", r)
circle = Circle.center_radius(Point(0,0), r)
d.draw(circle)

saveDrawing(d,'polyCircle.png')

