
# polyRandom.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Generate a polygon using n random points.

  Based on the in[7] code at
  https://github.com/cduck/hyperbolic/blob/master/examples/poincare.ipynb
  that generates polyRandom.svg

  Generates polyRandom.png
'''

import math, random
from geom import *
from pgeom import *


def randPoint():
  while True:
    # generate a (x,y) inside the Poincare disc
    x = 1-2*random.random()
    y = 1-2*random.random()
    try:
      return Point.euclid(x, y)
    except ValueError:   # may be ouside unit circle
      pass


n = int(input("no. of points in poly? "))
d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# Random d-points
pts = [randPoint() for _ in range(n)]
# print(*pts)
for p in pts:
  d.draw(p, radius=0.04, stroke='red')

# convert to a series of d-lines, including one from
# last point to the first
edges = toEdges(pts)
for edge in edges:
  d.draw(edge)

saveDrawing(d, 'polyRandom.png')
