
# polyRegular.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Generate a regular 5-sided polygon.

  Based on the in[8] code at
  https://github.com/cduck/hyperbolic/blob/master/examples/poincare.ipynb
  that generates polyRegular.svg

  Generates polyRegular.png
'''

import math
from geom import *
from pgeom import *


d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

p = 5
q = 4 
r = polyRadius(p, q)
print("Hyperbolic circumcircle radius:", r)
pts = [Point.polarEuclid(r, deg=-i*360/p)
                                for i in range(p)]

# blue edges
edges = toEdges(pts)
for edge in edges:
  print(edge)
  d.draw(edge)

# red vertices
for p in pts:
  d.draw(p, stroke='red')


saveDrawing(d, 'polyRegular.png')
