
# polyTransforms.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Various transforms: rotate, originStep, moveTo, 
  composition of translations

  Generates polyTransforms.png
'''

import math
from geom import *
from pgeom import *

def drawAsPoly(d, pts, color):
  edges = toEdges(pts)
  for edge in edges:
    d.draw(edge, stroke=color)


d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# points around the disk
d.draw(Point(0,0))
d.draw(Point(0,0.5), stroke='red')
d.draw(Point(0,1), stroke='green')
d.draw(Point(0.5,0), stroke='tan')
d.draw(Point(1,0), stroke='pink')


# 7-sided polygon (drawn in red)
p = 7
q = 3
print("p:", p, "; q:", q, ": Inner angle:", 360/q)
polyPts = polyVerts(p, q)
rot = Transform.rotate(deg=90)  
   # rotate so shape pointing up
polyPts = rot.asList(polyPts)
print("red poly points at 0, 1, -1:")
print("  ", polyPts[0], polyPts[1], polyPts[-1])
drawAsPoly(d, polyPts, 'red')

# move red poly's pt 0 to origin (drawn in blue)
toOrigin = Transform.originStep(polyPts[0])
tpts = toOrigin.asList(polyPts)
drawAsPoly(d, tpts, 'blue')

# move red poly up (green)
yStep = Transform.moveTo(Point(0, 0.5))
tpts = yStep.asList(polyPts)
drawAsPoly(d, tpts, 'green')

# move red poly right (pink)
xStep = Transform.moveTo(Point(0.5, 0))
tpts = xStep.asList(polyPts)
drawAsPoly(d, tpts, 'pink')

# move red poly up then right (tan/brown)
upRight = Transform.compose(xStep, yStep)
tpts = upRight.asList(polyPts)
drawAsPoly(d, tpts, 'tan')
drawLabel(d, "upRight", tpts[0].x+0.07, tpts[0].y, size=8)

# move red poly right then up (not the same result) (black)
rightUp = Transform.compose(yStep, xStep)
tpts = rightUp.asList(polyPts)
drawAsPoly(d, tpts, 'black')
drawLabel(d, "rightUp", tpts[0].x+0.07, tpts[0].y, size=8)

saveDrawing(d, 'polyTransforms.png')
