
# triMove.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Move a triangle using different vertices
  Generates triMove.png
'''

import math

from geom import *
from pgeom import *

d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# highlight (0,0.5)
pt = Point(0,0.5)
d.draw(pt, radius=0.05, fill='blue')

# a red triangle
p0 = Point(0,0)
p1 = Point(0,0.25)
p2 = Point(0.5,0.25)
tri1 = Triangle(p0,p1,p2)
d.draw(tri1, stroke='red', fill='red')
print("Triangle:", tri1)

v1 = tri1.getVertex(1)
print("Vertex 1:", v1)
drawLabel(d, "v1", *v1, size=8)

# moved triangle v0 to (0,0.5) (drawn in turquoise) 
trans = Transform.moveTo(Point(0, 0.5))
mvTri = tri1.transform(trans)
d.draw(mvTri, stroke='turquoise', fill='turquoise')
t1 = mvTri.getVertex(1)
print("Moved Turquoise Vertex 1:", t1)
drawLabel(d, "t1", *t1, size=8)

# move v1 to (0, 0.5) by first moving it to the origin
# drawn in brown
toOrigin = Transform.originStep(v1)
trans2 = Transform.compose(trans, toOrigin)
mvTri = tri1.transform(trans2)
d.draw(mvTri, stroke='brown', fill='brown')
b1 = mvTri.getVertex(1)
print("Moved Brown Vertex 1:", b1)
drawLabel(d, "b1", *b1, size=8, color='white')

saveDrawing(d,'triMove.png')
