
# triTransforms.py
# Andrew Davison, ad@coe.psu.ac.th, Sept. 2024
'''
  Various transforms applied to a triangle:
    rotate, mirror, moveTo, compose
  Generates triTransforms.png
'''

import math

from geom import *
from pgeom import *
import drawsvg


def mirrorEdge(tri, edgeNo):
  edge = tri.getEdge(edgeNo)
  return Transform.mirror(edge.startPt(), edge.endPt())



d = createDrawing()
d.draw(ECircle(0, 0, 1), stroke='silver') # disc boundary

# the original triangle (drawn in red)
p0 = Point(0,0)
p1 = Point(0,0.25)
p2 = Point(0.5,0.25)
tri1 = Triangle(p0,p1,p2)
d.draw(tri1, stroke='red', fill='red')
print("Red Vertex 1:", tri1.getVertex(1))

# ---------------------------------------
# rotations

# rotated triangle (around p0) (drawn in blue)
rot = Transform.rotate(deg=90)
rTri = tri1.transform(rot)
d.draw(rTri, stroke='blue', fill='blue')
print("Blue Vertex 1:", rTri.getVertex(1))


# rotate triangle 90 degrees around p1 (drawn in tan)
# using a mirror line at 45 degs
m1 = Transform.mirror(Point(-0.25,0), Point(0,0.25))
rTri = tri1.transform(m1)
d.draw(rTri, stroke='tan', fill='tan')
print("Tan Vertex 1:", rTri.getVertex(1))

# ---------------------------------------
# multiple mirrors

mTri = tri1.transform(mirrorEdge(tri1, 0))
d.draw(mTri, stroke='green', fill='green')
print("Green Vertex 1:", mTri.getVertex(1))

mTri = tri1.transform(mirrorEdge(tri1, 2))
d.draw(mTri, stroke='orange', fill='orange')
print("Orange Vertex 1:", mTri.getVertex(1))

mTri = mTri.transform(mirrorEdge(mTri, 1))
d.draw(mTri, stroke='pink', fill='pink')
print("Pink Vertex 1:", mTri.getVertex(1))

mTri = mTri.transform(mirrorEdge(mTri, 2))
d.draw(mTri, stroke='tan', fill='tan')
print("Tan Vertex 1:", mTri.getVertex(1))
drawLabel(d, "p1", *mTri.getVertex(1), size=8)

# ---------------------------------------
# moves

# move triangle's p0 to (0,0.5)
trans = Transform.moveTo(Point(0, 0.5))
tTri = tri1.transform(trans)
d.draw(tTri, stroke='turquoise', fill='turquoise')
print("Turquoise Vertex 2:", tTri.getVertex(2))

# move turquoise triangle's v2 to its v0 position
v2 = tri1.getVertex(2)  # original triangle
step2to0 = Transform.originStep(v2)
trans2 = Transform.compose(step2to0, trans)
tTri = tri1.transform(trans2)
d.draw(tTri, stroke='brown', fill='brown')
print("Brown Vertex 2:", tTri.getVertex(2))

# move  triangle's p2 to a polar coord using inverted()
stepPtto0 = Transform.originStep(
               Point.polarEuclid(0.1, deg=-135))
invStep = stepPtto0.inverted()
trans3 = Transform.compose(invStep, step2to0)
tTri = tri1.transform(trans3)
d.draw(tTri, stroke='pink', fill='pink')
v2 = tTri.getVertex(2)
print("Pink Vertex 2:", v2, "; dist:", math.hypot(*v2))

saveDrawing(d,'triTransforms.png')

